"""
Version information for NetworkX, created during installation.

Do not add this file to the repository.

"""

import datetime

version = '2.4'
date = 'Fri Nov 15 21:45:45 2019'

# Was NetworkX built from a development version? If so, remember that the major
# and minor versions reference the "target" (rather than "current") release.
dev = False

# Format: (name, major, min, revision)
version_info = ('networkx', '2', '4', None)

# Format: a 'datetime.datetime' instance
date_info = datetime.datetime(2019, 11, 15, 21, 45, 45)

# Format: (vcs, vcs_tuple)
vcs_info = (None, (None, None))

